aboutsummaryrefslogtreecommitdiffhomepage
path: root/internal/rosa/cmake.go
diff options
context:
space:
mode:
Diffstat (limited to 'internal/rosa/cmake.go')
-rw-r--r--internal/rosa/cmake.go7
1 files changed, 5 insertions, 2 deletions
diff --git a/internal/rosa/cmake.go b/internal/rosa/cmake.go
index 8a67f4bc..f9e5e38c 100644
--- a/internal/rosa/cmake.go
+++ b/internal/rosa/cmake.go
@@ -34,14 +34,17 @@ type CMakeHelper struct {
var _ Helper = new(CMakeHelper)
-// extra returns the cmake handle alongside either ninja or make.
-func (attr *CMakeHelper) extra() P {
+// tools returns the cmake handle alongside either ninja or make.
+func (attr *CMakeHelper) tools() P {
if attr != nil && attr.Make {
return P{_cmake, _make}
}
return P{_cmake, _ninja}
}
+// inputs is a noop.
+func (*CMakeHelper) inputs() P { return nil }
+
// wantsChmod returns false.
func (*CMakeHelper) wantsChmod() bool { return false }